GymDash

sim name 1
✓ X

#### kwargs

Key

This is a picture.

This is some audio.

This is some video.

Filter Option
Between
Control Request
MAIN SETTINGS
Theme
Viz Settings ⚙
Smooth Spread
Smooth Factor
Rescale Details Y-Axis
Hide Unselected Scalars
My tooltip

## Start

name:
key:
family:
type:

#### kwargs

## Control

#### kwargs

## Query

#### kwargs

Main Plots
Key:
Default

### Multimedia

#### Filter & Sort

Keys
Sims
Step

#### Videos

#### Images

This is a picture.

#### Audio

This is some audio.

### CONFIGS